@@ -17,11 +17,19 @@ from typing import Any, Dict, List, Type
 from botocore.client import ClientMeta
 
 from mypy_boto3_ce.type_defs import (
+    AnomalyDateIntervalTypeDef,
+    AnomalyMonitorTypeDef,
+    AnomalySubscriptionTypeDef,
     CostCategoryRuleTypeDef,
+    CreateAnomalyMonitorResponseTypeDef,
+    CreateAnomalySubscriptionResponseTypeDef,
     CreateCostCategoryDefinitionResponseTypeDef,
     DateIntervalTypeDef,
     DeleteCostCategoryDefinitionResponseTypeDef,
     DescribeCostCategoryDefinitionResponseTypeDef,
+    GetAnomaliesResponseTypeDef,
+    GetAnomalyMonitorsResponseTypeDef,
+    GetAnomalySubscriptionsResponseTypeDef,
     GetCostAndUsageResponseTypeDef,
     GetCostAndUsageWithResourcesResponseTypeDef,
     GetCostForecastResponseTypeDef,
@@ -38,8 +46,13 @@ from mypy_boto3_ce.type_defs import (
     GetUsageForecastResponseTypeDef,
     GroupDefinitionTypeDef,
     ListCostCategoryDefinitionsResponseTypeDef,
+    ProvideAnomalyFeedbackResponseTypeDef,
     RightsizingRecommendationConfigurationTypeDef,
     ServiceSpecificationTypeDef,
+    SubscriberTypeDef,
+    TotalImpactFilterTypeDef,
+    UpdateAnomalyMonitorResponseTypeDef,
+    UpdateAnomalySubscriptionResponseTypeDef,
     UpdateCostCategoryDefinitionResponseTypeDef,
 )
 
@@ -69,12 +82,14 @@ class Exceptions:
     RequestChangedException: Type[BotocoreClientError]
     ResourceNotFoundException: Type[BotocoreClientError]
     ServiceQuotaExceededException: Type[BotocoreClientError]
+    UnknownMonitorException: Type[BotocoreClientError]
+    UnknownSubscriptionException: Type[BotocoreClientError]
     UnresolvableUsageUnitException: Type[BotocoreClientError]
 
 
 class CostExplorerClient:
     """
-    [CostExplorer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client)
+    [CostExplorer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client)
     """
 
     meta: ClientMeta
@@ -82,7 +97,21 @@ class CostExplorerClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.can_paginate)
+        """
+
+    def create_anomaly_monitor(
+        self, AnomalyMonitor: "AnomalyMonitorTypeDef"
+    ) -> CreateAnomalyMonitorResponseTypeDef:
+        """
+        [Client.create_anomaly_monitor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
+        """
+
+    def create_anomaly_subscription(
+        self, AnomalySubscription: "AnomalySubscriptionTypeDef"
+    ) -> CreateAnomalySubscriptionResponseTypeDef:
+        """
+        [Client.create_anomaly_subscription documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
         """
 
     def create_cost_category_definition(
@@ -92,21 +121,31 @@ class CostExplorerClient:
         Rules: List["CostCategoryRuleTypeDef"],
     ) -> CreateCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.create_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
+        [Client.create_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
+        """
+
+    def delete_anomaly_monitor(self, MonitorArn: str) -> Dict[str, Any]:
+        """
+        [Client.delete_anomaly_monitor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.delete_anomaly_monitor)
+        """
+
+    def delete_anomaly_subscription(self, SubscriptionArn: str) -> Dict[str, Any]:
+        """
+        [Client.delete_anomaly_subscription documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.delete_anomaly_subscription)
         """
 
     def delete_cost_category_definition(
         self, CostCategoryArn: str
     ) -> DeleteCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.delete_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
+        [Client.delete_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
         """
 
     def describe_cost_category_definition(
         self, CostCategoryArn: str, EffectiveOn: str = None
     ) -> DescribeCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.describe_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
+        [Client.describe_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
         """
 
     def generate_presigned_url(
@@ -117,33 +156,64 @@ class CostExplorerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
+        """
+
+    def get_anomalies(
+        self,
+        DateInterval: AnomalyDateIntervalTypeDef,
+        MonitorArn: str = None,
+        Feedback: Literal["YES", "NO", "PLANNED_ACTIVITY"] = None,
+        TotalImpact: TotalImpactFilterTypeDef = None,
+        NextPageToken: str = None,
+        MaxResults: int = None,
+    ) -> GetAnomaliesResponseTypeDef:
+        """
+        [Client.get_anomalies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_anomalies)
+        """
+
+    def get_anomaly_monitors(
+        self, MonitorArnList: List[str] = None, NextPageToken: str = None, MaxResults: int = None
+    ) -> GetAnomalyMonitorsResponseTypeDef:
+        """
+        [Client.get_anomaly_monitors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_anomaly_monitors)
+        """
+
+    def get_anomaly_subscriptions(
+        self,
+        SubscriptionArnList: List[str] = None,
+        MonitorArn: str = None,
+        NextPageToken: str = None,
+        MaxResults: int = None,
+    ) -> GetAnomalySubscriptionsResponseTypeDef:
+        """
+        [Client.get_anomaly_subscriptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_anomaly_subscriptions)
         """
 
     def get_cost_and_usage(
         self,
         TimePeriod: "DateIntervalTypeDef",
+        Metrics: List[str],
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"] = None,
         Filter: Dict[str, Any] = None,
-        Metrics: List[str] = None,
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         NextPageToken: str = None,
     ) -> GetCostAndUsageResponseTypeDef:
         """
-        [Client.get_cost_and_usage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
+        [Client.get_cost_and_usage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
         """
 
     def get_cost_and_usage_with_resources(
         self,
         TimePeriod: "DateIntervalTypeDef",
+        Filter: Dict[str, Any],
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"] = None,
-        Filter: Dict[str, Any] = None,
         Metrics: List[str] = None,
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         NextPageToken: str = None,
     ) -> GetCostAndUsageWithResourcesResponseTypeDef:
         """
-        [Client.get_cost_and_usage_with_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
+        [Client.get_cost_and_usage_with_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
         """
 
     def get_cost_forecast(
@@ -163,7 +233,7 @@ class CostExplorerClient:
         PredictionIntervalLevel: int = None,
     ) -> GetCostForecastResponseTypeDef:
         """
-        [Client.get_cost_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
+        [Client.get_cost_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
         """
 
     def get_dimension_values(
@@ -205,7 +275,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetDimensionValuesResponseTypeDef:
         """
-        [Client.get_dimension_values documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
+        [Client.get_dimension_values documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
         """
 
     def get_reservation_coverage(
@@ -218,7 +288,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetReservationCoverageResponseTypeDef:
         """
-        [Client.get_reservation_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
+        [Client.get_reservation_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
         """
 
     def get_reservation_purchase_recommendation(
@@ -241,7 +311,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetReservationPurchaseRecommendationResponseTypeDef:
         """
-        [Client.get_reservation_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
+        [Client.get_reservation_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
         """
 
     def get_reservation_utilization(
@@ -253,7 +323,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetReservationUtilizationResponseTypeDef:
         """
-        [Client.get_reservation_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
+        [Client.get_reservation_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
         """
 
     def get_rightsizing_recommendation(
@@ -265,7 +335,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetRightsizingRecommendationResponseTypeDef:
         """
-        [Client.get_rightsizing_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
+        [Client.get_rightsizing_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
         """
 
     def get_savings_plans_coverage(
@@ -279,7 +349,7 @@ class CostExplorerClient:
         MaxResults: int = None,
     ) -> GetSavingsPlansCoverageResponseTypeDef:
         """
-        [Client.get_savings_plans_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
+        [Client.get_savings_plans_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
         """
 
     def get_savings_plans_purchase_recommendation(
@@ -301,7 +371,7 @@ class CostExplorerClient:
         Filter: Dict[str, Any] = None,
     ) -> GetSavingsPlansPurchaseRecommendationResponseTypeDef:
         """
-        [Client.get_savings_plans_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
+        [Client.get_savings_plans_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
         """
 
     def get_savings_plans_utilization(
@@ -311,7 +381,7 @@ class CostExplorerClient:
         Filter: Dict[str, Any] = None,
     ) -> GetSavingsPlansUtilizationResponseTypeDef:
         """
-        [Client.get_savings_plans_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
+        [Client.get_savings_plans_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
         """
 
     def get_savings_plans_utilization_details(
@@ -322,7 +392,7 @@ class CostExplorerClient:
         MaxResults: int = None,
     ) -> GetSavingsPlansUtilizationDetailsResponseTypeDef:
         """
-        [Client.get_savings_plans_utilization_details documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
+        [Client.get_savings_plans_utilization_details documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
         """
 
     def get_tags(
@@ -333,7 +403,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetTagsResponseTypeDef:
         """
-        [Client.get_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_tags)
+        [Client.get_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_tags)
         """
 
     def get_usage_forecast(
@@ -353,14 +423,41 @@ class CostExplorerClient:
         PredictionIntervalLevel: int = None,
     ) -> GetUsageForecastResponseTypeDef:
         """
-        [Client.get_usage_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
+        [Client.get_usage_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
         """
 
     def list_cost_category_definitions(
         self, EffectiveOn: str = None, NextToken: str = None, MaxResults: int = None
     ) -> ListCostCategoryDefinitionsResponseTypeDef:
         """
-        [Client.list_cost_category_definitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
+        [Client.list_cost_category_definitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
+        """
+
+    def provide_anomaly_feedback(
+        self, AnomalyId: str, Feedback: Literal["YES", "NO", "PLANNED_ACTIVITY"]
+    ) -> ProvideAnomalyFeedbackResponseTypeDef:
+        """
+        [Client.provide_anomaly_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.provide_anomaly_feedback)
+        """
+
+    def update_anomaly_monitor(
+        self, MonitorArn: str, MonitorName: str = None
+    ) -> UpdateAnomalyMonitorResponseTypeDef:
+        """
+        [Client.update_anomaly_monitor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.update_anomaly_monitor)
+        """
+
+    def update_anomaly_subscription(
+        self,
+        SubscriptionArn: str,
+        Threshold: float = None,
+        Frequency: Literal["DAILY", "IMMEDIATE", "WEEKLY"] = None,
+        MonitorArnList: List[str] = None,
+        Subscribers: List["SubscriberTypeDef"] = None,
+        SubscriptionName: str = None,
+    ) -> UpdateAnomalySubscriptionResponseTypeDef:
+        """
+        [Client.update_anomaly_subscription documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.update_anomaly_subscription)
         """
 
     def update_cost_category_definition(
@@ -370,5 +467,5 @@ class CostExplorerClient:
         Rules: List["CostCategoryRuleTypeDef"],
     ) -> UpdateCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.update_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
+        [Client.update_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
         """
